FBX Debug Viewer - Bone Roll & Animation

Ready to load rigged mesh

### Bone Info

Name
-
Parent
-
Index
-
Roll Angle (Z-rotation)
-
Local Position
X: - Y: - Z: -
Local Rotation (Euler XYZ)
X: - Y: - Z: -
Local Quaternion
-
Local Scale
-
World Position
X: - Y: - Z: -
World Rotation (Euler XYZ)
X: - Y: - Z: -
Bone Length
-
Children
-
FBX Debug Viewer - Bone Roll & Animation Debugging
Animation Playback
0.00s / 0.00s
Speed: 1.0x
Loop
Visualization
Skeleton Mesh X-Ray Bone Axes Bone Names
Size Controls
Bone Size: 1.0x
Axis Size: 1.0x
Label Size: 1.0x
Bone Filter
0/0 bones
Scene
Grid World Axes Wireframe
No mesh loaded